@@ -1,5 +1,5 @@
 from datetime import datetime
-from typing import Dict, List, Union
+from typing import Any, Dict, List, Type, Union
 
 from pydantic import AnyUrl, Field, root_validator, validator
 
@@ -23,7 +23,7 @@ from hsmodels.schemas.root_validators import (
     split_coverages,
     split_dates,
 )
-from hsmodels.schemas.validators import list_not_empty, parse_identifier, parse_sources
+from hsmodels.schemas.validators import list_not_empty, parse_identifier, parse_sources, parse_spatial_coverage
 
 
 class ResourceMetadata(BaseMetadata):
@@ -34,6 +34,8 @@ class ResourceMetadata(BaseMetadata):
     class Config:
         title = 'Resource Metadata'
 
+        schema_config = {'read_only': ['type', 'identifier', 'created', 'modified', 'published'], 'exclude': ['url']}
+
     type: str = Field(
         const=True,
         default="CompositeResource",
@@ -138,6 +140,7 @@ class ResourceMetadata(BaseMetadata):
 
     _parse_identifier = validator("identifier", pre=True)(parse_identifier)
     _parse_sources = validator("sources", pre=True)(parse_sources)
+    _parse_spatial_coverage = validator("spatial_coverage", pre=True)(parse_spatial_coverage)
 
     _language_constraint = validator('language', allow_reuse=True)(language_constraint)
     _creators_constraint = validator('creators')(list_not_empty)
